summaryrefslogtreecommitdiff
path: root/src/scm/webid-oidc/program.scm
diff options
context:
space:
mode:
Diffstat (limited to 'src/scm/webid-oidc/program.scm')
-rw-r--r--src/scm/webid-oidc/program.scm8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/scm/webid-oidc/program.scm b/src/scm/webid-oidc/program.scm
index 4fbc34a..4d469f3 100644
--- a/src/scm/webid-oidc/program.scm
+++ b/src/scm/webid-oidc/program.scm
@@ -1,4 +1,4 @@
;; webid-oidc, implementation of the Solid specification
;; Copyright (C) 2020, 2021 Vivien Kraus
;; This program is free software: you can redistribute it and/or modify
@@ -286,7 +286,7 @@
(car (command-line)))
(format #t (G_ "
-Run the webid-oidc COMMAND."))
+Run the disfluid COMMAND."))
(format #t "\n")
(format #t (G_ "
This program is covered by the GNU Affero GPL, version 3 or
@@ -361,7 +361,7 @@ Options for the resource server:"))
(format #t (G_ "
-H HEADER, --~a=HEADER:
the HEADER field contains the webid of the authenticated user,
- XXX-Agent by default. For the full server, disable webid-oidc
+ XXX-Agent by default. For the full server, disable Solid-OIDC
authentication.")
header-sym)
(format #t (G_ "
@@ -552,7 +552,7 @@ options for the parts."))
~a ~a \\
--~a 'https://webid-oidc.planete-kraus.eu/complete-corresponding-source.tar.gz' \\
--~a 'https://data.planete-kraus.eu' \\
- --~a '/var/lib/webid-oidc/server/key.jwk' \\
+ --~a '/var/lib/disfluid/server/key.jwk' \\
--~a 'https://data.planete-kraus.eu/vivien#me' \\
--~a '$...alg...$...salt...$...hash...' \\
--~a 'https://data.planete-kraus.eu/keys' \\
@@ -1,4 +1,4 @@
-;; webid-oidc, implementation of the Solid specification
+;; disfluid, implementation of the Solid specification
;; Copyright (C) 2020, 2021 Vivien Kraus
;; This program is free software: you can redistribute it and/or modify